


nu0fn <- function(u) {
  if (u <2/3) {
    res <- sin(3*u*pi)
  } else {
    res <- sin(6*u*pi - 6*pi)
  }
  res
}

nu1fn <- function(u) {
  if (u <2/3) {
    res <- sin(3/2*u*pi)
  } else {
    res <- sin(3*u*pi - 3*pi)
  }
  res
}

####################
ugrid <- seq(0,1,1e-3)
nu0grid <- sapply(ugrid,nu0fn)
nu1grid <- sapply(ugrid,nu1fn)

res <- data.frame(nu0=nu0grid,nu1=nu1grid)
res$nu0s <- sapply(ugrid,nu0fn) + .5
res$nu1s <- sapply(ugrid,nu1fn) + .5

cbp <- c("#56B4E9","#E69F00", "#009E73", "#CC79A7","#000000","#F0E442", "#0072B2", "#D55E00")
lt <- c("solid", "dashed", "longdash", "twodash", "dotdash")
require(ggplot2)

# Original Environment
orig_plot <- ggplot() + ylab("nu") + xlab("u") + #ggtitle("Original Environment") +
  geom_line(aes(x = ugrid, y = res$nu0, color = "nu0", linetype="nu0")) + 
  geom_line(aes(x = ugrid, y = res$nu1, color = "nu1", linetype="nu1")) +
  geom_hline(yintercept=0, linetype="solid", color="black") +
  scale_linetype_manual(values=c("nu0"=lt[1],"nu1"=lt[2])) +
  scale_color_manual(values=c("nu0"=cbp[1],"nu1"=cbp[2])) +
  labs(color = "nu", linetype = "nu") + theme_bw() +
  theme(plot.title = element_text(hjust = 0.5))
print(orig_plot)
ggsave("orig_plot.png", orig_plot, width = 10, height = 2, dpi = 300)

# Counterfactual Environment
cf_plot <- ggplot() + ylab("nu") + xlab("u") + #ggtitle("Counterfactual Environment") +
  geom_line(aes(x = ugrid, y = res$nu0s, color = "nu0", linetype="nu0")) + 
  geom_line(aes(x = ugrid, y = res$nu1s, color = "nu1", linetype="nu1")) +
  geom_hline(yintercept=0, linetype="solid", color="black") +
  scale_linetype_manual(values=c("nu0"=lt[1],"nu1"=lt[2])) +
  scale_color_manual(values=c("nu0"=cbp[1],"nu1"=cbp[2])) +
  labs(color = "nu", linetype = "nu") + theme_bw() +
  theme(plot.title = element_text(hjust = 0.5))
print(cf_plot)
ggsave("cf_plot.png", cf_plot, width = 10, height = 2, dpi = 300)

