
rm(list=ls())
source("PRTP-fn.R")

df <- readstata13::read.dta13("pums90.dta")
df$y <- df$mwfp
df$z <- df$samesex
df$t <- df$morekids
pobs <- empp(df)

# Obtain vector of max defiers devec
FS <- mean(df$t[df$z==1]) - mean(df$t[df$z==0])
OLS <- mean(df$y[df$t==1]) - mean(df$y[df$t==0]) #-0.1336895
lamvec <- seq(0,0.99,0.01)
devec <- lamvec/(1-lamvec)*FS
devec <- devec[devec<1]

# Get TSLS beta coefficient with controls
# Run FS and RF regressions with covariates to get coefficients
lmFS <- lm(t~z+agem+agefstm+boy1+boy2+white+black+hispanic,data=df)
lmRF <- lm(y~z+agem+agefstm+boy1+boy2+white+black+hispanic,data=df)
OLSCov <- lm(y~t+agem+agefstm+boy1+boy2+white+black+hispanic,data=df)$coefficients[2]
beta <- lmRF$coefficients[2]/lmFS$coefficients[2]

###############
## Get gam0
PrG6 <- PrG6fn(df,qD=0,CAC=0.01,NCN=0.01)

# Get alpha_NCp and coef_NCp
df1 <- df[df$z==1,]
df1$get_alphNCp <- 1- df1$t -PrG6[5] - PrG6[4] 
lmNCp <- lm(get_alphNCp~agem+agefstm+boy1+boy2+white+black+hispanic,data=df1)
# boy2 is perfectly correlated with boy1 by construction of df1 bcos samesex
alphNCp <- lmNCp$coefficients[1] 
coefW <- lmNCp$coefficients[2:8] 

# get alphaW
df$alphaW <- coefW[1]*df$agem + coefW[2]*df$agefstm + coefW[3]*df$boy1 +
  coefW[5]*df$white + coefW[6]*df$black + coefW[7]*df$hispanic

# predict p00y
df$p00 <- alphNCp + PrG6[5] + PrG6[2] + PrG6[3] + df$alphaW
df$p00y <- df$p00*df$y

# regress p00y on W's
df00 <- df[df$t==0&df$z==0,]
lm00 <- lm(p00y~(agem+agefstm+boy1+white+black+hispanic)+alphaW*(agem+agefstm+boy1+white+black+hispanic)
           ,data=df00)
gam0 <- unname(lm00$coefficients[1])

###############
## Threshold Crossing, Increasing Propensity CC,NC
fCCNC_TECst <- function(qD=0,CAC=0,NCN=0,NegTE=FALSE,minTE=NA){
  PrG6 <- PrG6fn(df,qD=qD,CAC=CAC,NCN=NCN)
  LATEstBounds(df,PrG6,K=c(0,1),NegTE=NegTE,minTE=minTE)$objval
}

FillCA0NC0 <- function(qD) fCCNC_TECst(qD=qD,CAC=0,NCN=0,
                                       NegTE=TRUE,minTE=-0.3)
FillCA1NC1 <- function(qD) fCCNC_TECst(qD=qD,CAC=0.01,NCN=0.01,
                                       NegTE=TRUE,minTE=-0.3)

CA0NC0Bounds <- t(sapply(devec,FillCA0NC0))
CA1NC1Bounds <- t(sapply(devec,FillCA1NC1))

# Set bounds
minCA0NC0=CA0NC0Bounds[,1]; maxCA0NC0=CA0NC0Bounds[,2]
minCA1NC1=CA1NC1Bounds[,1]; maxCA1NC1=CA1NC1Bounds[,2]

for (i in 1:length(devec)) {
  minCA0NC0[i] <- min(CA0NC0Bounds[1:i,1])
  maxCA0NC0[i] <- max(CA0NC0Bounds[1:i,2])
  minCA1NC1[i] <- min(CA1NC1Bounds[1:i,1])
  maxCA1NC1[i] <- max(CA1NC1Bounds[1:i,2])
}

###############
## Analogous plot with Covariates: Threshold Crossing, Increasing Propensity CC,NC
fCCNC_TECstCov <- function(qD=0,CAC=0,NCN=0,NegTE=FALSE,minTE=NA){
  PrG6 <- PrG6fn(df,qD=qD,CAC=CAC,NCN=NCN)
  LATEstBoundsCov(df,PrG6,beta=beta,gam0=gam0,alphNCp=alphNCp,
                  K=c(0,1),NegTE=NegTE,minTE=minTE)$objval
}

FillCA0NC0Cov <- function(qD) fCCNC_TECstCov(qD=qD,CAC=0,NCN=0,
                                       NegTE=TRUE,minTE=-0.3)
FillCA1NC1Cov <- function(qD) fCCNC_TECstCov(qD=qD,CAC=0.01,NCN=0.01,
                                       NegTE=TRUE,minTE=-0.3)

CA0NC0BoundsCov <- t(sapply(devec,FillCA0NC0Cov))
CA1NC1BoundsCov <- t(sapply(devec,FillCA1NC1Cov))

# Set bounds
minCA0NC0Cov=CA0NC0BoundsCov[,1]; maxCA0NC0Cov=CA0NC0BoundsCov[,2]
minCA1NC1Cov=CA1NC1BoundsCov[,1]; maxCA1NC1Cov=CA1NC1BoundsCov[,2]

for (i in 1:length(devec)) {
  minCA0NC0Cov[i] <- min(CA0NC0BoundsCov[1:i,1])
  maxCA0NC0Cov[i] <- max(CA0NC0BoundsCov[1:i,2])
  minCA1NC1Cov[i] <- min(CA1NC1BoundsCov[1:i,1])
  maxCA1NC1Cov[i] <- max(CA1NC1BoundsCov[1:i,2])
}

######################################
######################################
require("ggplot2")
## CC,NC Plot
plotdf <- data.frame(lambda = lamvec[which(devec<1)], 
                     minCA0NC0=minCA0NC0, maxCA0NC0=maxCA0NC0,
                     minCA1NC1=minCA1NC1, maxCA1NC1=maxCA1NC1,
                     minCA0NC0Cov=minCA0NC0Cov, maxCA0NC0Cov=maxCA0NC0Cov,
                     minCA1NC1Cov=minCA1NC1Cov, maxCA1NC1Cov=maxCA1NC1Cov)

# Color blind friendly palette
cbp <- c("#56B4E9","#E69F00", "#009E73", "#CC79A7")
lt <- c("solid", "dashed", "longdash", "twodash")

######################################
# CA,CC Plot
plot_gender_TCInc_CCNC <- ggplot() + ylab("Effect of 3rd kid on Labor Supply") + 
  xlab("lambda") + 
  geom_line(data = plotdf, aes(x = lambda, y = minCA0NC0, linetype = "LATE", color = "LATE")) + 
  geom_line(data = plotdf, aes(x = lambda, y = maxCA0NC0, linetype = "LATE", color = "LATE")) +
  geom_line(data = plotdf, aes(x = lambda, y = minCA1NC1, linetype = "LATE*", color = "LATE*")) + 
  geom_line(data = plotdf, aes(x = lambda, y = maxCA1NC1, linetype = "LATE*", color = "LATE*")) +
  scale_linetype_manual(values=c("LATE"=lt[1],"LATE*"=lt[2])) +
  scale_color_manual(values=c("LATE"=cbp[1],"LATE*"=cbp[2])) +
  labs(color = "Environment", linetype = "Environment") + theme_bw() +
  scale_x_continuous(breaks = seq(0, 0.9, by = .1),expand=c(0,0)) +
  scale_y_continuous(breaks = seq(-.3, 0, by = .02)) +
  #geom_hline(data = plotdf, aes(yintercept = minCA0NC0[1]),color="blue") +
  geom_hline(aes(yintercept = OLS ),color="red") +
  annotate("text",x=0.5,y=OLS+0.01,label="OLS")
print(plot_gender_TCInc_CCNC)
ggsave(file="plot_gender_TCInc_CCNC.png",plot=plot_gender_TCInc_CCNC, width = 10, height = 6, dpi = 300)

######################################
# CA,CC Plot with covariates
plot_gender_TCInc_CCNC_Cov <- ggplot() + ylab("Effect of 3rd kid on Labor Supply") + xlab("lambda") +
  geom_line(data = plotdf, aes(x = lambda, y = minCA0NC0Cov, linetype = "LATE", color = "LATE")) + 
  geom_line(data = plotdf, aes(x = lambda, y = maxCA0NC0Cov, linetype = "LATE", color = "LATE")) +
  geom_line(data = plotdf, aes(x = lambda, y = minCA1NC1Cov, linetype = "LATE*", color = "LATE*")) + 
  geom_line(data = plotdf, aes(x = lambda, y = maxCA1NC1Cov, linetype = "LATE*", color = "LATE*")) +
  scale_linetype_manual(values=c("LATE"=lt[1],"LATE*"=lt[2])) +
  scale_color_manual(values=c("LATE"=cbp[1],"LATE*"=cbp[2])) +
  labs(color = "Environment", linetype = "Environment") + theme_bw() +
  scale_x_continuous(breaks = seq(0, 0.9, by = .1),expand=c(0,0)) +
  scale_y_continuous(breaks = seq(-.3, 0, by = .02)) +
  #geom_hline(data = plotdf, aes(yintercept = minCA0NC0Cov[1]),color="blue") +
  geom_hline(aes(yintercept = OLSCov ),color="red") +
  annotate("text",x=0.5,y=OLSCov+0.01,label="OLS")
print(plot_gender_TCInc_CCNC_Cov)
ggsave(file="plot_gender_TCInc_CCNC_Cov.png",plot=plot_gender_TCInc_CCNC_Cov, width = 10, height = 6, dpi = 300)
